==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebColumnResizeEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnResizeEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnResizeEventArgsDescription, _super);
    function WebColumnResizeEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebColumnResizeEventArgsDescription.prototype.get_type = function () {
        return "WebColumnResizeEventArgs";
    };
    Object.defineProperty(WebColumnResizeEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebColumnResizeEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Detail");
        },
        enumerable: true,
        configurable: true
    });
    WebColumnResizeEventArgsDescription.$t = markType(WebColumnResizeEventArgsDescription, 'WebColumnResizeEventArgsDescription', Description.$);
    WebColumnResizeEventArgsDescription.__marshalByValue = true;
    WebColumnResizeEventArgsDescription.__marshalByValueAlias = "ColumnResizeEventArgs";
    return WebColumnResizeEventArgsDescription;
}(Description));
export { WebColumnResizeEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebColumnResizeEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnResizeEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnResizeEventArgsDescription, _super);
    function WebColumnResizeEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        return _this;
    }
    WebColumnResizeEventArgsDescription.prototype.get_type = function () {
        return "WebColumnResizeEventArgs";
    };
    Object.defineProperty(WebColumnResizeEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnResizeEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Detail");
        },
        enumerable: false,
        configurable: true
    });
    WebColumnResizeEventArgsDescription.$t = markType(WebColumnResizeEventArgsDescription, 'WebColumnResizeEventArgsDescription', Description.$);
    WebColumnResizeEventArgsDescription.__marshalByValue = true;
    WebColumnResizeEventArgsDescription.__marshalByValueAlias = "ColumnResizeEventArgs";
    return WebColumnResizeEventArgsDescription;
}(Description));
export { WebColumnResizeEventArgsDescription };
